/*
 * Copyright 2000 Draagon Software, Inc. All Rights Reserved.
 *
 * This software is the proprietary information of Draagon Software, Inc.
 * Use is subject to license terms.
 *
 */

package com.draagon.wii;

import java.util.List;
import java.io.*;

import com.draagon.wii.util.NameValuePair;

/**
 * The WIIConnector interface defines the methods that any Draagon Web Integrator
 * connectors must implement.  A connector can use any method of connecting to
 * an external system, but they are all required to accept the request
 * parameters and to return an IO stream for the response as well as returning
 * the response paramters.
 * <p>
 * The WIIKernel uses objects that implement this interface to connect to the
 * external system and process the request and response.
 *
 * @author  Doug Mealing
 * @version 1.1, 12/17/00
 * @see     com.draagon.wii.WIIKernel
 * @since   JDK1.2
 */
public interface WIIConnector
{
  /**
   * Peform the request against the external system.
   *
   * @param req The WIIRequest object that can be used to access additional
   *              information about the request.
   * @param headers The request headers that are to be passed to the external
   *                system.
   * @exception  WIIException  This exception is used if any errors are
   *                            encountered.
   * @return  The input stream to read the response from the external system.
   */
  public InputStream doRequest( WIIRequest req, List<NameValuePair> headers )
    throws IOException, WIIException;

  /**
   * Returns the response headers from the external system.
   *
   * @return  The external system response headers.
   */
  public List<NameValuePair> getResponseHeaders();

  /**
   * Returns the content type of the response.
   *
   * @return  The external system content type.
   */
  public String getContentType();

  /**
   * Returns the status code from the request.
   *
   * @return The response status code
   */
  public int getStatusCode();
}
