/*
 * Copyright 2000 Draagon Software, Inc. All Rights Reserved.
 *
 * This software is the proprietary information of Draagon Software, Inc.
 * Use is subject to license terms.
 *
 */

package com.draagon.wii;

import java.util.List;

import com.draagon.wii.util.NameValuePair;

/**
 * The WIIResponseHeaders interface defines the methods that any Draagon Web Integrator
 * response header objects must implement.  A parameter object is used to add, remove,
 * or modify response headers once returned from the external system.
 * These objects are activated by the WIIKernel class.
 *
 * @author  Doug Mealing
 * @version 1.1, 12/17/00
 * @see     com.draagon.wii.WIIKernel
 * @since   JDK1.2
 */
public interface WIIResponseHeaders
{
  /**
   * Handle the response headers from the external system.
   *
   * @param req The WIIRequest object that can be used to access additional
   *              information about the request, such as the client's request
   *              parameters.
   * @param res The WIIResponse object that can be used to handle custom
   *              output based on the response headers returned.
   * @param headers The response headers that are to be passed to the external
   *                system.
   * @exception  WIIException  This exception is used if any errors are
   *                            encountered.
   */
  public void processResponseHeaders( WIIRequest req, WIIResponse res, List<NameValuePair> headers )
    throws WIIException;
}
