/*
 * Copyright 2000 Draagon Software, Inc. All Rights Reserved.
 *
 * This software is the proprietary information of Draagon Software, Inc.
 * Use is subject to license terms.
 *
 */

package com.draagon.wii;

import java.io.*;

import org.w3c.dom.*;

/**
 * The WIIService interface defines the methods that any Draagon Web Integrator
 * services (or services) must implement.  A service is used to process embedded
 * XML tags in the external system's response content.
 * <p>
 * The WIIServiceStream object calls the services while parsing the embedded XML
 * tags.
 *
 * @author  Doug Mealing
 * @version 1.1, 12/17/00
 * @see     com.draagon.wii.streams.WIIServiceStream
 * @since   JDK1.2
 */
public interface WIIService
{
  /**
   * Processes the XML tags and returns a string to be embedded in the response.
   *
   * @param node The XML DOM node to be processed.
   * @param pw The PrintWriter stream to send any output to
   * @exception  WIIException  This exception is used if any errors are
   *                            encountered, possibly with the XML.
   * @return  The string to embed in the response.
   */
  public void process( Node node, WIIResponse res ) throws IOException, WIIException;

  /**
   * Sets the WIIRequest object so that it can be used later.
   *
   * @param req The WIIRequest object to store.
   */
  public void setRequest( WIIRequest req );

  /**
   * Returns the Service names that cause this Service to be called.  This
   * enumeration should contain the names of all tags that need to be processed
   * by this Service.
   *
   * @return  The enumeration of tag names.
   */
  public String getName();

  public void setName( String name );
}
