
/**
 * Title:        Draagon Web Integrator<p>
 * Description:  Draagon Web Integrator is a web application integration framework.<p>
 * Copyright:    Copyright (c) Doug Mealing<p>
 * Company:      Draagon Software, Inc.<p>
 * @author Doug Mealing
 * @version 1.0
 */
package com.draagon.wii.device;

import com.draagon.wii.*;

import java.io.*;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class HtmlDevice implements WIIDevice
{
  private static Log log = LogFactory.getLog( HtmlDevice.class );

  public HtmlDevice()
  {
  }

  // return the device name
  public String getName()
  {
    return "Standard HTML";
  }

  public void writeMessage( WIIRequest request, PrintWriter out, String msg, String detailed )
    throws IOException
  {
    out.println( msg + "<!-- " + detailed + "-->" );
  }

  // Embed an error message in the device (using comments if possible)
  public void writeError( WIIRequest request, PrintWriter out, String msg, String description )
    throws IOException
  {
    out.println( msg + "<!-- " + description + "-->" );
  }

  // Return an access error
  public void returnAccessError( WIIRequest request, WIIResponse res, String msg, String description )
    throws IOException
  {
    PrintWriter pw = res.getWriter();

    pw.println( "<h1>" + msg + "</h1>" );
    pw.println( "<h2>" + description + "</h2>" );
  }

  // Return a normal message
  public void returnMessage( WIIRequest request, WIIResponse response, String msg, String description )
    throws IOException
  {
    ////////////////////////////////////////////////////
    // Attempt to send message

    PrintWriter out = response.getWriter();

    out.println("<html><HEAD><TITLE>Jasmine Draagon Web Integrator</TITLE></HEAD><BODY bgcolor=white text=black>\n");
    // out.println("<h2>" + mServletName + "</h2>\n");
    out.println("<b>Version:  " + WIIKernel.VERSION + "</b><br>\n");
    if ( msg != null ) out.println("<b>Message:  " + msg + "</b><br>\n");
    if ( description != null ) out.println("<b><font color=blue>" + description + "</font></b><br>\n");
    out.println("</BODY></html>\n");
    out.close();
  }

  // Return an error message
  public void returnError( WIIRequest request, WIIResponse response, String msg, String description )
    throws IOException
  {
    returnError( request, response, msg, description, null );
  }

  public void returnError( WIIRequest request, WIIResponse response, String msg, String description, Exception e )
    throws IOException
  {
    if ( log.isDebugEnabled() )
    {
      if ( e != null ) log.error( msg, e );
      else log.error( msg );
    }

    ////////////////////////////////////////////////////
    // Attempt to inform user of the error

    PrintWriter out = response.getWriter();

    out.println("<html><HEAD><TITLE>Jasmine Draagon Web Integrator</TITLE></HEAD><BODY bgcolor=white text=black>\n");
    //out.println("<h2>" + mServletName + "</h2>\n");
    out.println("<b>Version:  " + WIIKernel.VERSION + "</b><br>\n");
    if ( msg != null ) out.println("<b><font color=red>ERROR:" + msg + "</font></b><br>\n");
    if ( description != null ) out.println("<b><font color=#ddaa00>DESCRIPTION:  " + description + "</font></b><br>\n");
    if ( e != null )
    {
        out.println("<p><b>Stack Trace</b><br>\n");
        out.println("<i>" + e.getMessage() + "</i><br>\n");
        e.printStackTrace( out );
        out.println("</p>\n");
    }
    out.println("</BODY></html>\n");
    out.close();
  }
}
