/**
 * Title:        Draagon Web Integrator<p>
 * Description:  Draagon Web Integrator is a web application integration framework.<p>
 * Copyright:    Copyright (c) Doug Mealing<p>
 * Company:      Draagon Software, Inc.<p>
 * @author Doug Mealing
 * @version 1.0
 */
package com.draagon.wii.servlet;

import com.draagon.wii.*;

import java.io.*;
import java.util.List;
import java.util.Date;
import javax.servlet.http.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class WIIServletRequest extends WIIServletRequestAdapter
{
  private WIIServlet mWII = null;
  private WIIDevice mDevice = null;
  private WIISite mSite = null;
  private WIIUser mUser = null;
  private WIITemplate mTemplate = null;
  private WIIKernel mKernel = null;
  private int mExternalCode = 200;

  private WIIServletContext mContext = null;

  private static Log log = LogFactory.getLog( WIIServletRequest.class );

  public WIIServletRequest( HttpServletRequest req, WIIServlet serv )
  {
    super( req );
    //mMetaData = metadata;
    mWII = serv;

    mKernel = mWII.getKernel();
    mContext = new WIIServletContext( mWII.getServletContext() );
  }

  public void setUser( WIIUser user )
  {
    mUser = user;
  }

  public void setSite( WIISite site )
  {
    mSite = site;
  }

  public void setDevice( WIIDevice device )
  {
    mDevice = device;
  }

  public WIIDevice getDevice()
  {
    return mDevice;
  }

  public void setTemplate( WIITemplate template )
  {
    mTemplate = template;
  }

  public WIITemplate getTemplate()
  {
    return mTemplate;
  }

  public WIIContext getContext()
  {
    return mContext;
  }

  public WIIServlet getServlet()
  {
    return mWII;
  }

  public WIIKernel getKernel()
  {
    return mKernel;
  }

  public WIIConfiguration getConfiguration()
  {
    return mWII.getConfiguration();
  }

  public WIIUser getUser()
  {
    return mUser;
  }

  public WIISite getSite()
  {
    return mSite;
  }

  public void setExternalStatusCode( int code )
  {
    mExternalCode = code;
  }

  public int getExternalStatusCode()
  {
    return mExternalCode;
  }

  public String formFullURL()
    throws WIIException
  {
    String url = null;

    String p = mReq.getProtocol();

    if ( p.indexOf( "HTTPS" ) >= 0 )
      url = "https://";
    else if ( p.indexOf( "HTTP" ) >= 0 )
      url = "http://";
    else
      throw new WIIException( "(WIIServletRequest.formFullURL) Unknown protocol type: [" + p + "]" );

    url += mReq.getServerName();
    int port = mReq.getServerPort();

    if ( port != 80 ) url += ":" + port;

    return url;
  }

  public String getWIIURL()
    throws WIIException
  {
    return mWII.getWIIURL( this );
  }

  public String getSiteURL( WIISite site )
    throws WIIException
  {
    if ( site.getName().equals( "ROOT" )) return getWIIURL();
    return getWIIURL() + "/" + site.getName();
  }

  public String getSiteURL()
    throws WIIException
  {
    return getSiteURL( mSite );
  }

  public WIIService getWIIService( String name )
    throws WIIException
  {
    // Attempt to get global services
    WIIService f = super.getWIIService( name );

    // Attempt to load Service settings from configuration
    if ( f == null ) f = mWII.getWIIService( name, mSite );
    if ( f != null ) f.setRequest( this );
    return f;
  }

  public List<WIIRequestHeaders> getWIIRequestHeaders()
    throws WIIException
  {
    return mWII.getWIIRequestHeaders( mSite );
  }

  public List<WIIResponseHeaders> getWIIResponseHeaders()
    throws WIIException
  {
    return mWII.getWIIResponseHeaders( mSite );
  }

  public WIIConnector getWIIConnector()
    throws WIIException
  {
    return mWII.getWIIConnector( mSite );
  }

  public WIIStream getWIIStream( String content )
    throws WIIException
  {
    WIIStream tmp = mWII.getWIIStream( mSite, content );
    if ( tmp != null ) tmp.setRequest( this );
    return tmp;
  }

  public void logError( String msg, Exception e )
  {
    ////////////////////////////////////////////////////
    // Log to the debug file on errors only

    String tmp = mReq.getPathInfo();
    if ( mReq.getQueryString() != null ) tmp += mReq.getQueryString();

    StringWriter sw = new StringWriter();
    PrintWriter pw = new PrintWriter( sw );

    pw.println( "---------------------------------------------------------------------------" );
    pw.println( "Message:   " + msg );
    pw.println( "Timestamp: " + ( new Date() ).toString() );
    pw.println( "Request:   {" + mReq.getMethod() + "} " + tmp );

    if ( mSite != null ) pw.println( "Site:      {" + mSite.getName() + "} " + mSite.getExternalURL( mReq.getPathInfo() ));
    if ( mUser != null ) pw.println( "User:      " + mUser.get( WIIUser.WII_USERNAME ) + " - " + mUser.get( WIIUser.WII_REALNAME ));

    if ( e != null )
      log.error( sw.toString(), e );
    else
      log.error( sw.toString() );
  }

  public String getServletPath()
  {
    return mReq.getContextPath() + mReq.getServletPath();
  }
}
