/*
 * Copyright 2000 Draagon Software, Inc. All Rights Reserved.
 *
 * This software is the proprietary information of Draagon Software, Inc.
 * Use is subject to license terms.
 *
 */

package com.draagon.wii.streams;

import com.draagon.wii.*;


import java.io.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class WIITextStream implements WIIStream
{
  private WIIRequest mRequest = null;
  // private InputStream mOs = null;

  protected boolean mNoParse = false;

  private static Log log = LogFactory.getLog( WIITextStream.class );

  /**
   * Input buffer for decompression.
   */
  // protected byte[] buf;
  // protected String outbuf = "";

  /**
   * Length of input buffer.
   */
  protected int len = 0;
  protected int mark = 0;

  // this flag is set to true after EOF has reached
  //private boolean reachEOF = false;

  public WIITextStream()
  {
    // buf = new byte[ size ];
  }

  public void setRequest( WIIRequest req )
  {
    mRequest = req;
    // mOs = req.getExternalInputStream();
  }

  public WIIRequest getRequest()
  {
    return mRequest;
  }

  public String getContentType()
  {
    return mRequest.getExternalContentType();
  }

  public void process( WIIResponse res )
    throws IOException, WIIException
  {
    int rc = 0;

    if ( getContentType() != null && getContentType().toLowerCase().startsWith( "text" ))
    {
      if ( log.isDebugEnabled() )
        log.debug( "(process) Processing binary data [" + getContentType() + "]: " + mRequest.getPathInfo() );

      byte buf[] = new byte[ 4096 ];
      Writer out = res.getWriter();
      InputStream is = mRequest.getExternalInputStream();

      while(( rc = is.read( buf, 0, 4096 )) >= 0 )
      {
        char [] cbuf = new char[ rc ];
        for( int x=0; x<rc; x++ ) cbuf[ x ] = (char) buf[ x ];
        if ( rc >= 0 ) out.write( cbuf, 0, rc );
      }
    }
    else
    {
      if ( log.isDebugEnabled() )
        log.debug( "(process) Processing binary data [" + getContentType() + "]: " + mRequest.getPathInfo() );

      byte buf[] = new byte[ 4096 ];
      OutputStream out = res.getOutputStream();
      InputStream is = mRequest.getExternalInputStream();

      while(( rc = is.read( buf, 0, 4096 )) >= 0 )
      {
        if ( rc >= 0 ) out.write( buf, 0, rc );
      }
    }
  }
}
