package com.draagon.wii.ui;

/**
 * Title:        Draagon Web Integrator
 * Description:  Draagon Web Integrator is a web application integration framework.
 * Copyright:    Copyright (c) Doug Mealing
 * Company:      Draagon Software, Inc.
 * @author Doug Mealing
 * @version 1.0
 */

import com.draagon.wii.*;

import java.io.*;
import org.w3c.dom.*;

public abstract class BoxService extends UIService
{

  public BoxService()
  {
  }


  /**
   * This method returns the requested user property string.
   *
   * @param node The XML DOM node to parse to retrieve the user property to
   *              return.
   * @exception  WIIException  This exception is not thrown when an error
   *                            occurs retrieving the user information or the
   *                            XML cannot be processed properly.
   * @return  The user property string to embed in the response.
   */
  public void process( Node node, WIIResponse res )
    throws IOException, WIIException
  {
    if ( node instanceof Element )
    {
      String type = ((Element) node ).getAttribute( "type" );
      String title = ((Element) node ).getAttribute( "title" );

      String t = null;
      if ( type.compareToIgnoreCase( "top" ) == 0 ) t = "top";
      if ( type.compareToIgnoreCase( "bottom" ) == 0 ) t = "bottom";
      if ( t == null )
        throw new WIIException( "The type parameter must be 'top' or 'bottom' for the BOX service" );

      drawBox( res, t, title );
    }
    else
      throw new WIIException( "Node was not an Element" );
  }

  public abstract void drawBox( WIIResponse res, String type, String title )
    throws IOException, WIIException;
}