
/**
 * Title:        Draagon Web Integrator<p>
 * Description:  Draagon Web Integrator is a web application integration framework.<p>
 * Copyright:    Copyright (c) Doug Mealing<p>
 * Company:      Draagon Software, Inc.<p>
 * @author Doug Mealing
 * @version 1.0
 */
package com.draagon.wii.ui;

import com.draagon.wii.*;
import com.draagon.wii.util.*;

import java.io.*;
import java.util.List;

import org.w3c.dom.*;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class TemplateService extends UIService implements WIIResponseHeaders
{
  private static Log log = LogFactory.getLog( TemplateService.class );

  /**
   * Empty Constructor
   */
  public TemplateService()
  {
  }

  /**
   * Processes the XML tags and returns a string to be embedded in the response.
   *
   * @param node The XML DOM node to be processed.
   * @exception  WIIException  This exception is used if any errors are
   *                            encountered, possibly with the XML.
   * @return  The string to embed in the response.
   */
  public void process( Node node, WIIResponse res )
    throws IOException, WIIException
  {
    PrintWriter pw = res.getWriter();
    pw.print( "<b>Not Implemented</b>" );
  }

  public void processResponseHeaders( WIIRequest req, WIIResponse res, List<NameValuePair> headers )
    throws WIIException
  {
    // Make sure a template exists
    WIITemplate template = req.getTemplate();
    if ( template == null ) return;

    // Make sure it is HTML
    String content = req.getExternalContentType();

    int code = req.getExternalStatusCode();
    
    // If it's not HTML or it's not a 200 status code, don't do this
    if ( content == null || content.toLowerCase().indexOf( "html" ) == -1
        || code != 200 )
      return;

    // Get the frame to use from the properties if it exists there
    String frameType = req.getConfiguration().getSiteProperty( req.getSite(), "frame" );
    if ( frameType == null || frameType.isEmpty() ) frameType = WIITemplate.THICK;
    
    // Look for it in the headers otherwise
    for(NameValuePair pair : headers )
    {
      String name = (String) pair.getName();

      // System.out.println( "{" + name + "} <" + retProps.getProperty( name ) + ">" );

      // Check for the WII_Frame parameter
      if ( name.compareToIgnoreCase( "X-WII-Frame" ) == 0 )
      {
        String ftype = pair.getValue();
        if ( ftype.compareToIgnoreCase( "Thick" ) == 0 )
          frameType = WIITemplate.THICK;
        else if ( ftype.compareToIgnoreCase( "Thin" ) == 0 )
          frameType = WIITemplate.THIN;
        else if ( ftype.compareToIgnoreCase( "None" ) == 0 )
          frameType = WIITemplate.NONE;
      }
      else if ( name.compareToIgnoreCase( "X-WII-Title" ) == 0 )
      {
        String title = pair.getValue();
        if ( title != null )
          template.setAttribute( "title", title );
      }
    }

    if ( log.isDebugEnabled() )
      log.debug( "(WIIKernel.serviceExternal) Frame Type: " + frameType );

    template.setFrameMode( frameType );
  }
}
