/*
 * Copyright 2000 Draagon Software, Inc. All Rights Reserved.
 *
 * This software is the proprietary information of Draagon Software, Inc.
 * Use is subject to license terms.
 *
 */
package com.draagon.wii.util;

import java.io.*;
import java.net.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class HttpCall
{
    private static Log log = LogFactory.getLog( HttpCall.class );
    private URL mUrl;

    /**
     * Instantiate a new PortalConnection object with the given URL
     *
     * @param  URL
     */
    public HttpCall( String url )
    {
      try
      {
        mUrl = new URL( url );
      }
      catch ( Exception e )
      {
        log.error( "(HttpCall) Could not create URL [" +url+ "]", e );
      }
    }

    /**
     * The getData method is a general method for writing requests and
     * reading responses from a URL. The return type is a byte array, as the
     * request may on certain occasions return a file. When character data is
     * required, use the getDataAsString() method.
     *
     * @return byte[]   The data returned by the Portal to respond to this request
     */
    public byte[] getData()
        throws IOException
    {
      ByteArrayOutputStream baos = new ByteArrayOutputStream();

      URLConnection conn = mUrl.openConnection();
      if ( conn == null )
      {
        log.error( "(getData) Could not open connection [" +mUrl.toString()+ "]" );
        return null;
      }

      InputStream is = conn.getInputStream();
      if ( is == null )
      {
        log.error( "(getData) Could not get input stream [" +mUrl.toString()+ "]" );
        return null;
      }

      BufferedInputStream bis = new BufferedInputStream( is );

      byte[] buf = new byte[1024];
      int read = -1;
      // System.out.println( "PortalConnection:  Reading data" );
      while ( ( read = bis.read( buf, 0, 1024 ) ) != -1 )
      {
          baos.write( buf, 0, read );
          // System.out.println( "Read " + read + " bytes" );
      }

      if ( bis != null ) bis.close();

      // System.out.println( "Returning byte array" );
      return baos.toByteArray();
    }

    public String getResponse()
        throws IOException
    {
      if ( mUrl == null )
      {
        log.error( "(getResponse) URL is null" );
        return null;
      }

      byte [] b = getData();
      if ( b == null ) return null;
      return new String( b );
    }

    public URL getURL()
    {
      return mUrl;
    }
}
